# -*- coding: utf-8 -*-
"""
Created on Fri Mar 27 20:51:15 2020

@author: msmsa
"""
from .InputData import InputData
from pathlib import Path

class Reproc_Input(InputData):
    def __init__(self,input_data_path = None):
        if input_data_path:
            self.input_data_path = input_data_path
        else:
            self.input_data_path = Path(__file__).parent/'Data/Reprocessing_Input.csv'
        
        # Initialize the superclass 
        super().__init__(self.input_data_path,eval_parameter=True)                  


# -*- coding: utf-8 -*-
"""
Created on Mon Sep 16 16:26:54 2019

@author: msardar2
"""
from .InputData import InputData
from pathlib import Path
import pandas as pd
import ast

class LF_Input(InputData):
    def __init__(self,input_data_path = None):
        if input_data_path:
            self.input_data_path = input_data_path
        else:
            self.input_data_path = Path(__file__).parent/'Data/LF_Input.csv'

        # Initialize the superclass 
        super().__init__(self.input_data_path)
        
        self.gas_emission_factor=pd.read_csv(Path(__file__).parent/'Data/LF_Gas_emission_factors.csv',converters={'Biosphere_key': ast.literal_eval})
        self.gas_emission_factor.fillna('',inplace=True)
        
        self.lcht_coef = pd.read_csv(Path(__file__).parent/'Data/LF_Leachate_Coeff.csv',converters={'Surface_water': ast.literal_eval,'Ground_water': ast.literal_eval})
        self.lcht_coef.fillna(0,inplace=True)
        
        self.lcht_Alloc = pd.read_csv(Path(__file__).parent/'Data/LF_Leachate_Allocation.csv')


# -*- coding: utf-8 -*-
"""
Created on Mon Sep  2 15:49:46 2019

@author: msardar2
"""
from stats_arrays import *
import numpy as np
import pandas as pd
from pathlib import Path

class MC():
    def __init__(self,input_list):
        self.input_list = input_list
        
    def setup_MC(self,seed=None):
        self.list_var = list()
        self.sens_analysis={}
        self.run_index=0
        self.max_run = 10000000
        k=0
        for x in self.input_list.values():
            for y in x:
                self.list_var.append(x[y])
                if 'list' in x[y].keys():
                    self.sens_analysis[k] = x[y]['list']
                    self.max_run = min(self.max_run,len(x[y]['list']))
                k+=1
        self.Vars  = UncertaintyBase.from_dicts(*self.list_var)
        self.rand = MCRandomNumberGenerator(self.Vars,seed=seed)
      
    def gen_MC(self):
        data = self.rand.next()
        if len(self.sens_analysis) > 0:
            for x in self.sens_analysis.keys():
                data[x] = self.sens_analysis[x][self.run_index] 
            self.run_index+=1
            if self.run_index > self.max_run:
                raise ValueError('Number of runs are more than the number of defined inputs') 
        i=0
        variables = []
        for x in self.input_list.keys():
            for y in self.input_list[x]:
                if not np.isnan(data[i]):  
                    self.input_list[x][y]['amount'] = data[i]
                    variables.append( ( (x , y) , data[i]) )
                i+=1
        return(variables)
		
    def create_uncertainty_from_inputs(self,sheet_name,process_data,seed=None):
        self.process_data=process_data
        self.process_data_1=pd.read_excel(Path(__file__).parent/'Data/Material properties - process modles.xlsx', sheet_name = sheet_name, index_col = 'Parameter')
        self.uncertain_dict = dict()
        cols = list(self.process_data_1)
        for col in range(0,len(cols),7):
            self.uncertain_dict[cols[col]] = list()
            for val in range(len(self.process_data[cols[col]][3:])):
                self.uncertain_dict[cols[col]].append(dict())
                if not np.isnan(self.process_data_1[cols[col+1]][3+val]):
                    self.uncertain_dict[cols[col]][val]['uncertainty_type'] = int(self.process_data_1[cols[col+1]][3+val])
                    self.uncertain_dict[cols[col]][val]['loc'] = self.process_data_1[cols[col+2]][3+val]
                    self.uncertain_dict[cols[col]][val]['scale'] = self.process_data_1[cols[col+3]][3+val]
                    self.uncertain_dict[cols[col]][val]['shape'] = self.process_data_1[cols[col+4]][3+val]
                    self.uncertain_dict[cols[col]][val]['minimum'] = self.process_data_1[cols[col+5]][3+val]
                    self.uncertain_dict[cols[col]][val]['maximum'] = self.process_data_1[cols[col+6]][3+val]
                else:
                    self.uncertain_dict[cols[col]][val]['uncertainty_type'] = 1
							
        self.variables = dict()
        self.rng = dict()
        for key in self.uncertain_dict.keys():
            self.variables[key] = UncertaintyBase.from_dicts(*self.uncertain_dict[key])
            self.rng[key] = MCRandomNumberGenerator(self.variables[key],seed=seed)
		
    def uncertainty_input_next(self):
        data = dict()
        variables = list()
        for key in self.rng.keys():
            data[key] = self.rng[key].next()
            for val in range(len(self.process_data[key][3:])):
                if not np.isnan(data[key][val]):			
                    self.process_data.at[(self.process_data_1.index.values[3+val]),key] = data[key][val]
                    variables.append(((key,self.process_data_1.index.values[3+val]),data[key][val]))
        return variables
	



# -*- coding: utf-8 -*-
"""
Created on Tue Apr 21 20:45:14 2020

@author: msmsa
"""
import pandas as pd
import numpy as np
from .MC import *
from pathlib import Path
import ast

class InputData(MC):
    def __init__(self,input_data_path,eval_parameter=False):
        self.input_data_path = input_data_path            
        self.Data=pd.read_csv(self.input_data_path,dtype={'amount':float,'uncertainty_type':float,'loc':float,
                                                      'scale':float,'shape':float,'minimum':float,'maximum':float})

        if eval_parameter:     
            self.Data['Parameter']=self.Data['Parameter'].apply(ast.literal_eval)
        
        # Setting uncertainty type to 0 : Undefined ; when it is not defined
        self.Data['uncertainty_type'].fillna(0,inplace=True)
        #self.Data=self.Data.where((pd.notnull(self.Data)),None) 
        self.Input_list = {}
        self.keys = self.Data.columns[3:]
        for i in range(len(self.Data)):
            if self.Data.Category[i] not in self.Input_list.keys():
                exec("self.%s = {}" % self.Data.Dictonary_Name[i])
                exec("self.Input_list[self.Data.Category[i]] = self.%s" % self.Data.Dictonary_Name[i])
                exec("self.%s[self.Data.Parameter[i]] = dict(zip(self.keys,self.Data.loc[i,'Name':]))" % self.Data.Dictonary_Name[i])
            else:
                exec("self.%s[self.Data.Parameter[i]] = dict(zip(self.keys,self.Data.loc[i,'Name':]))" % self.Data.Dictonary_Name[i])

### Update_Input
    def Update_input(self,NewData):
        for i in NewData.index:
            exec("self.%s[NewData.Parameter[i]] = dict(zip(self.keys,NewData.loc[i,'Name':]))" %NewData.Dictonary_Name[i])
            self.Data.loc[i]=NewData.loc[i]
            
### Monte_carlo          
    def setup_MC(self,seed=None):
        super().__init__(self.Input_list)
        super().setup_MC(seed)


# -*- coding: utf-8 -*-
"""
Created on Mon Jul  1 21:17:40 2019

@author: msardar2
"""
import pandas as pd
import numpy as np
from ..MC import *
class Composting_input(MC):
    def __init__(self,input_data_path=None):
        if input_data_path:
            raise ValueError('Wrong input file, you cannot use input_data_path with input_script')
    
### Assumed Composition 
        self.Assumed_Comp = [0.1915,0.1447,0.1414,0.3977,0.0221,0.0035,0.0000,0.0031,0.0004,0.0035,0.0102,0.0019,0.0006,0.0015,
                             0.0019,0.0015,0.0000,0.0206,0.0011,0.0020,0.0038,0.0000,0.0000,0.0000,0.0055,0.0158,0.0008,0.0002,
                             0.0005,0.0006,0.0000,0.0000,0.0001,0.0077,0.0033,0.0022,0.0000,0.0000,0.0000,0.0102,0.0000,0.0000,
                             0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000]


### Operating Parameters
        self.Op_Param = {
                'Taod':{"Name":"Annual operating days","amount":260,"unit":'days/year',"Reference":None},
                'Tdoh':{"Name":"Daily operating hours","amount":8,"unit":'hours/day',"Reference":None},
                'Tact':{"Name":"Active composting time","amount":70,"unit":'days',"Reference":None},
                'Tcur':{"Name":"Curing time","amount":30,"unit":'days',"Reference":None}
                }
        
### Substrate Parameters
        self.Sawdust = {
                        'Bulk_Density':{"Name":"Bulk Density","amount":240,"unit":"kg/m3","Reference":'25'},
                       'Moisture_Content':{"Name":"Moisture Content","amount":0.39,"unit":None,"Reference":'25'},
                       'Volatile Solids':{"Name":"Volatile Solids","amount":0.906,"unit":None,"Reference":'25'},
                       'C_Cont':{"Name":"C_Cont","amount":53.4,"unit":"%","Reference":'25'},
                       'N_Cont':{"Name":"N_Cont","amount":0.25,"unit":"%","Reference":'25'},
                       'Pre screen out proportion':{"Name":"Pre screen out proportion","amount":0.05,"unit":None,"Reference":'25'},
                       'Post screen out proportion':{"Name":"Post screen out proportion","amount":1,"unit":None,"Reference":'25'},
                       'Proportion Vacuumed Out':{"Name":"Proportion Vacuumed Out","amount":1,"unit":None,"Reference":'25'},
                       'C Emitted':{"Name":"C Emitted","amount":18,"unit":"%","Reference":'25'},
                       'VS loss per C loss':{"Name":"VS loss per C loss","amount":2,"unit":None,"Reference":'25'}
                       }
        
        self.Wood_Chips = {
                        'Bulk_Density':{"Name":"Bulk Density","amount":320,"unit":"kg/m3","Reference":'25'},
                        'Moisture_Content':{"Name":"Moisture Content","amount":0.5,"unit":None,"Reference":'25'},
                        'Volatile Solids':{"Name":"Volatile Solids","amount":0.906,"unit":None,"Reference":'25'}
                            }
        
        self.Screen_Rejects = {'Moisture_Content':{"Name":"Moisture Content","amount":0.2678,"unit":None,"Reference":'25'},
                               'Volatile Solids':{"Name":"Volatile Solids","amount":0.8825,"unit":None,"Reference":'25'},
                               'C_Cont':{"Name":"C_Cont","amount":48.1,"unit":"%","Reference":'25'},
                               'N_Cont':{"Name":"N_Cont","amount":0.1,"unit":"%","Reference":'25'},
                               'Pre screen out proportion':{"Name":"Pre screen out proportion","amount":0,"unit":None,"Reference":'25'},
                               'Post screen out proportion':{"Name":"Post screen out proportion","amount":90,"unit":None,"Reference":'25'},
                               'Proportion Vacuumed Out':{"Name":"Proportion Vacuumed Out","amount":1,"unit":None,"Reference":'25'}
                               }
        
### Degradation Parameters
        self.Degradation_Parameters={
                'CN':{"Name":"inimum CN target at beginning of active composting","amount":30,"unit":"kg C/kg N","Reference":None},
                'initMC':{"Name":"Minimum initial moisture content","amount":0.55,"unit":None,"Reference":None},
                'MCac':{"Name":"Moisture content after active composting","amount":0.5,"unit":None,"Reference":None},
                'MCcu':{"Name":"Moisture content after curing","amount":0.45,"unit":None,"Reference":None},
                'densfinComp':{"Name":"Final compost bulk density","amount":700,"unit":'kg/m3',"Reference":None},
                'acDegProp':{"Name":"Proportion of mass loss that occurs during active composting","amount":90,"unit":'%',"Reference":None},
                }

### Material Properties
        self.Material_Properties ={
            'densFC':{'Name':'Density of final compost','amount':700 ,'unit':'kg/m3','Referenc':None},
            'densPeat':{"Name":"Density of peat","amount":200,"unit":'kg/m3',"Reference":None},
            'PeatSubFac':{"Name":"Volumetric peat replacement factor","amount":1,"unit":None,"Reference":None}
            }

### Biological Degredation
        self.Biological_Degredation = {
                'pCasCH4':{"Name":"Proportion of emitted C emitted as CH4","amount":0.017,"unit":None,"Reference":'12'},
                'pNasNH3':{"Name":"Proportion of emitted N emitted as NH3","amount":0.04,"unit":None,"Reference":'31'},
                'pNasN2O':{"Name":"Proportion of emitted N emitted as N2O","amount":0.004,"unit":None,"Reference":'12'},
                'bfCH4re':{"Name":"Biofilter CH4 removal efficiency","amount":0.15,"unit":None,"Reference":'18'},
                'bfNH3re':{"Name":"Biofilter NH3 removal efficiency","amount":48,"unit":'%',"Reference":'18'},
                'bfN2Ore':{"Name":"Biofilter N2O removal efficiency","amount":0,"unit":'%',"Reference":'18'},
                'preNH3toNOx':{"Name":"Proportion of removed NH3 that becomes NOx","amount":1,"unit":None,"Reference":'18'},
                'preNH3toN2O':{"Name":"Proportion of removed NH3 that becomes Nitrous Oxide","amount":0,"unit":None,"Reference":'18'},
                'bfVOCre':{"Name":"Biofilter VOC removal efficiency","amount":18,"unit":'%',"Reference":'32'},
                'percCStor':{"Name":"Percent of carbon in compost remaining after 100 years","amount":10,"unit":'%',"Reference":'5'},
                'percCStor_LF':{"Name":"Percent of carbon in compost remaining after 100 years","amount":100,"unit":'%',"Reference":None},
                'humFormFac':{"Name":"100 year carbon storage from humus formation","amount":0,"unit":'kg-C/kg-C in Compost',"Reference":'6'}
                }
        
### Land application inputs
        self.Land_app = {
                'perN2Oevap':{"Name":"Percent of applied N evaporated as N2O","amount":1.5,"unit":'%',"Reference":'16'},
                'perNH3evap':{"Name":"Percent of Ammonia that evaporates","amount":15,"unit":'%',"Reference":'16'},
                'perNasNH3fc':{"Name":"Percent N that is Ammonia","amount":50,"unit":'%',"Reference":'16'},
                'distLand':{"Name":"Haul distance to land","amount":20,"unit":'km',"Reference":None},
                'land_payload':{"Name":"Actual payload of truck used to haul soil amendment","amount":7.3,"unit":'Mg',"Reference":None},
                }

### Odor Control System
        self.Odor_Cont = {
                'Moc':{"Name":"OC blower power required per air flow rate","amount":0,"unit":'kW/cmm',"Reference":'4'},
                'ocReqAF':{"Name":"Odor control air flow required","amount":0,"unit":'m3/Mgpd',"Reference":'19'}
                }
        
### Vacuum Cleaning System
        self.Vaccum_sys = {
                'vacDiesFac':{"Name":"Diesel use","amount":0.22,"unit":'L/Mg',"Reference":'8'},
                'vacElecFac':{"Name":"Vacuum electricity (diesel by default)","amount":0,"unit":'kWh/Mg',"Reference":None}
                }

### Screening
        self.Screen = {
                'Mtr':{"Name":"Energy required per weight of post-screened material","amount":0.9,"unit":'kWh/Mg',"Reference":'9'}
                }        
        
### Curing
        self.Curing = {
                'Ftc':{"Name":"Frequency of turning during curing phase","amount":0.14,"unit":'1/day',"Reference":'21,19,20'}
                }         
        
### Front End Loader
        self.Loader = {
                'hpfel':{"Name":"Front end loader energy required per weight flow of material","amount":0.336,"unit":'kW/Mgd',"Reference":'10'},
                'Mffel':{"Name":"Front end loader specific fuel consumption","amount":0.26,"unit":'L/kWh',"Reference":'16'}
                }          

### Office Area
        self.Office = {
                'Mta':{"Name":"Office Area required per ton per day of material","amount":1.7,"unit":'m2/Mgpd',"Reference":'10'},
                'Mea':{"Name":"Energy required to power an office","amount":290,"unit":'kWh/m2-yr',"Reference":'11'}
                }         
        
### Avoided Fertilizer Production Offsets
        self.Fertilizer_offset = {
                'choice_BU':{"Name":"Offset Beneficial Use of Compost? (0=no; 1=yes)","amount":1,"unit":None,"Reference":None},
                'peatOff':{"Name":"Soil amendment offset peat (1) or no (0)","amount":1,"unit":None,"Reference":None},
                'fertOff':{"Name":"Soil amendment offset fertilizer (1) or no (0)","amount":1,"unit":None,"Reference":None}
                }              
        
### Active Compost Force Aeration        
        self.AC_Aeration = {
                'Aeff':{"Name":"Motor efficiency","amount":0,"unit":'kW-in/kW-out',"Reference":'4'},
                'Bhp':{"Name":"Blower power","amount":0,"unit":'kW',"Reference":'19'},
                'Breq':{"Name":"Blowers required per dry mass compost.","amount":0,"unit":'1/Mg',"Reference":'16,20'},
                'blPropON':{"Name":"Proportion of the time that blowers are on","amount":0,"unit":None,"Reference":'20'}
                } 

### Active Compost Windrow Turning   
        
# =============================================================================
# =============================================================================
# # Mwta unit should be kWh/Mg.turn        
# =============================================================================
# =============================================================================
        
        self.AC_Turning = {
                'Mwta':{"Name":"Windrow turner power rating","amount":0.24,"unit":'kWh/Mg',"Reference":'3'},
                'Mwfa':{"Name":"The fuel consumption of a windrow turner","amount":0.127,"unit":'L/kWh',"Reference":'3'},
                'Fta':{"Name":"Turning frequency","amount":0.33,"unit":'1/days',"Reference":None}
                }   
        
### Waste Shredding
        self.Shredding = {
                'Mtgp':{"Name":"Grinder power rating.","amount":10.6,"unit":'kWh/Mg',"Reference":'3'},
                'Mtgf':{"Name":"Grinder fuel consumption","amount":0.25,"unit":'L/kWh',"Reference":'3'}
                }
        
### In-Vessel
        self.Vessel = {
                'Minv':{"Name":"Vessel energy use per weight of material","amount":0,"unit":'kWh/Mg',"Reference":'27'}
                }
        
### Monte_carlo          
    def setup_MC(self,seed=None):
        self.Input_list = {'Op_Param':self.Op_Param, 'Sawdust':self.Sawdust, 'Wood_Chips':self.Wood_Chips,
                'Screen_Rejects':self.Screen_Rejects, 'Degradation_Parameters':self.Degradation_Parameters,
                'Material_Properties':self.Material_Properties,'Biological_Degredation':self.Biological_Degredation, 'Land_app':self.Land_app, 'Odor_Cont':self.Odor_Cont,
                'Vaccum_sys':self.Vaccum_sys,'Screen':self.Screen,'Curing':self.Curing, 'Loader':self.Loader,
                'Office':self.Office,'Fertilizer_offset':self.Fertilizer_offset, 'AC_Aeration':self.AC_Aeration,
                'AC_Turning':self.AC_Turning,'Shredding':self.Shredding,'Vessel':self.Vessel}
        super().__init__(self.Input_list)
        super().setup_MC(seed)
#################################################################
#### Convering the input dictionaries to csv file
#################
# =============================================================================
# A= Composting_input()
# A.setup_MC()
# category=[]
# Parameter=[]
# Name=[]
# amount=[]
# unit=[]
# 
# for x in A.Input_list.keys():
#     for y in  A.Input_list[x].keys():
#         category.append(x)
#         Parameter.append(y)
#         Name.append(A.Input_list[x][y]['Name'])
#         amount.append(A.Input_list[x][y]['amount'])
#         unit.append(A.Input_list[x][y]['unit'])
# AAA={'category':category,'Parameter':Parameter,'Name':Name,'amount':amount,'unit':unit}
# =============================================================================



# -*- coding: utf-8 -*-
"""
Created on Wed Mar 27 12:25:05 2019

@author: msardar2
"""
from .InputData import InputData
from pathlib import Path
import pandas as pd

class WTE_Input(InputData):
    def __init__(self,input_data_path = None):
        if input_data_path:
            self.input_data_path = input_data_path
        else:
            self.input_data_path = Path(__file__).parent/'Data/WTE_Input.csv'
        # Initialize the superclass 
        super().__init__(self.input_data_path)
        
        self.process_data=pd.read_excel(Path(__file__).parent/'Data/Material properties - process modles.xlsx', sheet_name = 'WTE', index_col = 'Parameter')
        self.process_data.fillna(0,inplace=True)


# -*- coding: utf-8 -*-
"""
Created on Wed Jul 17 16:37:44 2019

@author: msardar2
"""
import pandas as pd
import numpy as np
from ..MC import *
class AD_input(MC):
    def __init__(self,input_data_path=None):
        if input_data_path:
            raise ValueError('Wrong input file, you cannot use input_data_path with input_script')

### Assumed Composition 
        self.Assumed_Comp = [0.1587847314,0.1199794853,0.1172076820,0.3296762444,0.0824190611,0.0065468408,0.0000264482,
                             0.0058447349,0.0006849813,0.0065073226,0.0191333727,0.0034644248,0.0010472311,0.0028584798,
                             0.0036027383,0.0027399253,0.0000264482,0.0385170270,0.0021076349,0.0038200882,0.0070342313,
                             0.0000264482,0.0000264482,0.0000264482,0.0103537562,0.0295859243,0.0015148626,0.0002897998,
                             0.0009484357,0.0012118900,0.0000264482,0.0000264482,0.0001317272,0.0143846079,0.0061648320,
                             0.0041098880,0.0000264482,0.0000264482,0.0000264482,0.0190635573,0.0,0.0,0.0,0.0,0.0,0.0,
                             0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0]       


### Land application inputs
        self.Land_app = {
                'distLand':{"Name":"Distance to application site","amount":20,"unit":'km',"Reference":None},
                'erLand':{"Name":"Empty return from land application (0=no; 1=yes)","amount":1,"unit":'0/1',"Reference":None},
                'land_payload':{"Name":"Actual payload of truck used to haul soil amendment","amount":7.3,"unit":'Mg',"Reference":None},
                'ad_PeatSubFac':{"Name":"Volumetric peat replacement factor","amount":1,"unit":None,"Reference":'17'},
                'ad_densPeat':{"Name":"Density of peat","amount":200,"unit":'kg/m3',"Reference":'17'},
                'perN2Oevap':{"Name":"Percent of applied N evaporated as N2O","amount":1.5,"unit":'%',"Reference":'16'},
                'perNH3evap':{"Name":"Percent of Ammonia that evaporates","amount":15,"unit":'%',"Reference":'16'},
                'perNasNH3fc':{"Name":"Percent N that is Ammonia","amount":50,"unit":'%',"Reference":'16'},
                }

### Curing Biological Degradation
        self.Curing_Bio = {
                'ad_pCasCH4':{'Name':'Proportion of emitted C emitted as CH4','amount':0.017,'unit':None,'Referenc':'19'},
                'ad_pNasNH3':{'Name':'Proportion of emitted N emitted as NH3','amount':0.04,'unit':None,'Referenc':'26'},
                'ad_pNasN2O':{'Name':'Proportion of emitted N emitted as N2O','amount':0.004,'unit':None,'Referenc':'19'},
                'dmRed_Dig':{'Name':'VS reduction of digestate during curing','amount':0.3,'unit':None,'Referenc':'29'},
                'VSlossPerCloss':{'Name':'Mass of VS loss per mole of C loss','amount':12,'unit':'g/mol C','Referenc':None},
                }

### Curing Windrow Turning
        self.Windrow_turn = {
                'Tcur':{'Name':'Retention time in windrows','amount':21 ,'unit':'days','Referenc':None},
                'Mwta':{'Name':'Turning energy required per ton of compost','amount':0.24 ,'unit':'kWh/Mg','Referenc':None},
                'Mwfa':{'Name':'The fuel consumption of a windrow turner','amount':0.13 ,'unit':'L/kWh','Referenc':None},
                'turnFreq':{'Name':'Turning frequency','amount':0.43 ,'unit':'1/days','Referenc':None}
                }
        
        
### Facility Operation
        self.AD_operation = {
                'ad_lifetime':{'Name':'Facility economic lifetime','amount':20,'unit':'years','Referenc':None},
                'ophrsperday':{'Name':'Daily operating hours','amount':8,'unit':'hours','Referenc':None},
                'opdaysperyear':{'Name':'Annual operating days','amount':260,'unit':'days','Referenc':None},
                'retentionTime':{'Name':'Average retention time in reactor','amount':21,'unit':'days','Referenc':None},
                'recircMax':{'Name':'Maximum proportion of reactor water that can come from recirculation','amount':0.8,'unit':'fraction','Referenc':None},
                'isDw':{'Name':'Dewater digestate? (0=no; 1=yes)','amount':1,'unit':'0/1','Referenc':None},
                'isCured':{'Name':'Cure digestate solids stream? (0=no; 1=yes)','amount':1,'unit':'0/1','Referenc':None},
                'choice_BU':{'Name':'Digestate Beneficial Use (1) or No Beneficial Use (0)','amount':1,'unit':'0/1','Referenc':None},
                'peatOff':{'Name':'Digestate Beneficial Use offsets Peat (1 - Yes; 0 - No)','amount':1,'unit':'0/1','Referenc':None},
                'fertOff':{'Name':'Digestate Beneficial Use offsets Fertilizer (1 - Yes; 0 - No)','amount':1,'unit':'0/1','Referenc':None},
                }
### Biogas Generation and Use
        self.Biogas_gen = {
                'ad_ch4prop':{'Name':'Proportion of methane in collected biogas','amount':0.6,'unit':None,'Referenc':'28'},
                'ad_ch4stoich':{'Name':'Stoichiometric proportion of methane in produced biogas due to feedstock','amount':0.6,'unit':None,'Referenc':None},
                'ad_ch4EngCont':{'Name':'Methane energy content','amount':37.7,'unit':'MJ/m3','Referenc':None},
                'perLeak':{'Name':'Methane leakage','amount':3,'unit':'%','Referenc':'28'},
                'perSolDec':{'Name':'Percent of biogas mass from solid decomposition','amount':89,'unit':'%','Referenc':None,'Comment':'Average of cellulose (90%) and hemicellulose (88%)'},
                'ad_HeatRate':{'Name':'Heat rate for electrical energy generation','amount':9.86,'unit':'MJ/kWh','Referenc':'24'},
                'ad_collEff':{'Name':'Collection efficiency of biogas as proportion (0 to 1)','amount':0.97,'unit':None,'Referenc':None},
                'ad_downTime':{'Name':'Proportion of gas that is flared w/out electricity generation (0 to 1)','amount':0.03,'unit':None,'Referenc':None},
                }

### Biogas Combustion Emissions Factors
        self.emission_Flare = {  
                        'CH4_destruction':{'Name':'Methane destruction efficiency (0-1)','amount':0.999,'unit':None,'Referenc':None},
                        'CO':{'Name':'Carbon monoxide (CO)','amount':2.4,'unit':'g/GJ CH4 input','Referenc':None},
                        'NO2':{'Name':'Nitrogen oxides (as NO2)','amount':19.7,'unit':'g/GJ CH4 input','Referenc':None},
                        'SO2':{'Name':'Sulfur dioxide (SO2)','amount':23.3,'unit':'g/GJ CH4 input','Referenc':None},
                        'NMVOC':{'Name':'NMVOCs','amount':0,'unit':'g/GJ CH4 input','Referenc':None},
                        'PM':{'Name':'PM2.5','amount':36.9,'unit':'g/GJ CH4 input','Referenc':None},
                        }
        self.emission_Engine = {  
                        'CH4_destruction':{'Name':'Methane destruction efficiency (0-1)','amount':0.99,'unit':None,'Referenc':None},
                        'CO':{'Name':'Carbon monoxide (CO)','amount':273,'unit':'g/GJ CH4 input','Referenc':None},
                        'NO2':{'Name':'Nitrogen oxides (as NO2)','amount':540,'unit':'g/GJ CH4 input','Referenc':None},
                        'SO2':{'Name':'Sulfur dioxide (SO2)','amount':19.2,'unit':'g/GJ CH4 input','Referenc':None},
                        'NMVOC':{'Name':'NMVOCs','amount':105,'unit':'g/GJ CH4 input','Referenc':None},
                        'PM':{'Name':'PM2.5','amount':0.206,'unit':'g/GJ CH4 input','Referenc':None},
                            }

### Digestate Liquids Treatment
        self.Digestate_treatment = {
                'ad_distPOTW':{'Name':'Haul distance to treatment facility','amount':25 ,'unit':'km','Referenc':'15'},
                'ad_erPOTW':{'Name':'Empty return from treatment facility (1-Yes, 0-No)','amount':1 ,'unit':'0/1','Referenc':'15'},
                'payload_POTW':{'Name':'Actual payload of truck to treatment facility','amount':23 ,'unit':'Mg','Referenc':None},
                'er_wwtpLF':{'Name':'Empty return from LF to WWTP (1-Yes, 0-No)','amount':1 ,'unit':'0/1','Referenc':None},
                'payload_LFPOTW':{'Name':'Actual payload of truck to LF from WWTP','amount':23 ,'unit':'Mg','Referenc':None},
                'lchBODcont':{'Name':'BOD','amount':2.3 ,'unit':'kg/m3','Referenc':'28'},
                'lchCODcont':{'Name':'COD','amount':61.610 ,'unit':'kg/m3','Referenc':'31'},
                'lchTSScont':{'Name':'Total suspended solids','amount':1.450 ,'unit':'kg/m3','Referenc':'28'},
                'conc_totN':{'Name':'Total N','amount':1.350 ,'unit':'kg/m3','Referenc':'28'},
                'conc_Fe':{'Name':'Iron','amount':0 ,'unit':'kg/m3','Referenc':None},
                'conc_Cu':{'Name':'Copper','amount':0 ,'unit':'kg/m3','Referenc':None},
                'conc_Cd':{'Name':'Cadmium','amount':0.00003 ,'unit':'kg/m3','Referenc':39},
                'conc_As':{'Name':'Arsenic','amount':0 ,'unit':'kg/m3','Referenc':None},
                'conc_Hg':{'Name':'Mercury','amount':0.000026 ,'unit':'kg/m3','Referenc':39},
                'conc_P':{'Name':'Phosphate','amount':0.06 ,'unit':'kg/m3','Referenc':39},
                'conc_Se':{'Name':'Selenium','amount':0 ,'unit':'kg/m3','Referenc':None},
                'conc_Cr':{'Name':'Chromium','amount':0 ,'unit':'kg/m3','Referenc':None},
                'conc_Pb':{'Name':'Lead','amount':0.00261 ,'unit':'kg/m3','Referenc':39},
                'conc_Zn':{'Name':'Zinc','amount':0.0108 ,'unit':'kg/m3','Referenc':39},
                'conc_Ba':{'Name':'Barium','amount':0 ,'unit':'kg/m3','Referenc':None},
                'conc_Ag':{'Name':'Silver','amount':0 ,'unit':'kg/m3','Referenc':None},
                'wwtp_lf_dist':{'Name':'Distance from WWTP to landfill','amount':25 ,'unit':'km','Referenc':None}
                }
### Screening
        self.Post_Screen ={
                'ad_engScreen':{"Name":"Post-screen specific electricity consumption","amount":0.000882,"unit":'kWh/kg',"Reference":7},
                'ad_scrEff_WC':{"Name":"Proportion of wood chips remaining after post-screening","amount":0.75,"unit":'fraction',"Reference":None}
                }

### Material Properties
        self.Material_Properties ={
            'ad_mcReactor':{'Name':'Reactor moisture content','amount':0.92 ,'unit':'mass water/total mass','Referenc':20},
            'ad_mcFC':{'Name':'Finished compost moisture content','amount':0.45 ,'unit':'mass water/total mass','Referenc':None},
            'ad_densFC':{'Name':'Density of final compost','amount':700 ,'unit':'kg/m3','Referenc':2},
            'wcMC':{'Name':'Wood chip moisture content','amount':0.1586 ,'unit':'%','Referenc':None},
            'wcVSC':{'Name':'Wood chip VS content','amount':0.906 ,'unit':'%TS','Referenc':None}
            }
        
### Dewatering Parameters
        self.Dewater ={
            'elec_dw':{'Name':'Electricity Use','amount':75 ,'unit':'kWh/Mg TS throughput','Referenc':None},
            'ad_mcDigestate':{'Name':'Moisture Content of Solids Stream After Dewatering','amount':0.76 ,'unit':'mass water/total mass','Referenc':None}
            }

### Digestate Properties 
        self.Dig_prop = {
                'mcInitComp':{'Name':'Composting beginning moisture content (used to calculate wood chip requirements)','amount': 0.6,'unit':'mass water/total mass','Referenc':None},
                'digliqdens':{'Name':'Digestate Liquids Density','amount':1 ,'unit':'kg/L','Referenc':None},
                'perNSolid':{'Name':'Percent N to solids','amount':96 ,'unit':'%','Referenc':None},
                'perPSolid':{'Name':'Percent P to solids','amount':98.7 ,'unit':'%','Referenc':None},
                'perKSolid':{'Name':'Percent K to solids','amount':98.7 ,'unit':'%','Referenc':None}
                }

### Facility Energy Use
        self.Fac_Energy = {
        'Dsl_facility':{'Name':'Diesel fuel used by anaerobic digestion facility (not curing)','amount':0.3 ,'unit':'L/Mg','Referenc':28},
        'elec_preproc':{'Name':'Pre-processing Electricity Use','amount':9 ,'unit':'kWh/Mg','Referenc':28},
        'elec_facility':{'Name':'AD facility electricity use (excluding pre-process, dewatering, and curing)','amount':49 ,'unit':'kWh/Mg','Referenc':28}
                }  

### Front End Loader
        self.Loader = {
                'hpFEL':{"Name":"Front end loader use per facility capacity.","amount":0.168 ,"unit":'kW/Mgd',"Reference":'5'},
                'mfFEL':{"Name":"Front end loader specific fuel consumption.","amount":0.26 ,"unit":'L/kWh',"Reference":'6'}
                }

### Wood Chip Shredding
        self.shredding ={
                'Mtgp':{"Name":"Grinder power rating.","amount":10.6,"unit":'kWh/Mg',"Reference":'9'},
                'Mtgf':{"Name":"Grinder fuel consumption","amount":0.25,"unit":'L/kWh',"Reference":'9'}
                }

### Soil Sequestration
        self.Soil_seq ={
                'perCStor':{"Name":"Percent of carbon in finished compost remaining after 100 years","amount":10,"unit":'%',"Reference":'3'},
                'percCStor_LF':{"Name":"Percent of carbon in compost remaining after 100 years","amount":100,"unit":'%',"Reference":None},
                'humFormFac':{"Name":"100 year carbon storage from humus formation","amount":0,"unit":'kg-C/kg-C in compost',"Reference":'4'}
                }        
        
### Monte_carlo          
    def setup_MC(self,seed=None):
        self.Input_list = {'Land_app':self.Land_app,'Curing_Bio':self.Curing_Bio,'Windrow_turn':self.Windrow_turn,'AD_operation':self.AD_operation,'Biogas_gen':self.Biogas_gen,
                          'emission_Flare':self.emission_Flare, 'emission_Engine':self.emission_Engine,
                          'Digestate_treatment':self.Digestate_treatment,'Post_Screen':self.Post_Screen,'Material_Properties':self.Material_Properties,'Dewater':self.Dewater,
                          'Dig_prop':self.Dig_prop,'Fac_Energy':self.Fac_Energy, 'Loader':self.Loader,'shredding':self.shredding,'Soil_seq':self.Soil_seq}
        super().__init__(self.Input_list)
        super().setup_MC(seed)



#################################################################
#### Convering the input dictionaries to csv file
#################
# =============================================================================
# A= AD_input()
# A.setup_MC()
# category=[]
# Parameter=[]
# Name=[]
# amount=[]
# unit=[]
# 
# for x in A.Input_list.keys():
#     for y in  A.Input_list[x].keys():
#         category.append(x)
#         Parameter.append(y)
#         Name.append(A.Input_list[x][y]['Name'])
#         amount.append(A.Input_list[x][y]['amount'])
#         unit.append(A.Input_list[x][y]['unit'])
# AAA={'category':category,'Parameter':Parameter,'Name':Name,'amount':amount,'unit':unit}
# =============================================================================




#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
'pandas',
'xlrd',
'stats-arrays',
'jupyter'
]

setup_requirements = [ ]

package_input_data = {'swolfpy_inputdata.Data':['AD_Input.csv',
                                'CommonData.csv',
                                'Technosphere_LCI.csv',
                                'Technosphere_References.csv',
                                'Composting_Input.csv',
                                'LF_Gas_emission_factors.csv',
                                'LF_Input.csv',
                                'LF_Leachate_Allocation.csv',
                                'LF_Leachate_Coeff.csv',
                                'LF_Gas_emission_factors.xlsx',
                                'LF_Leachate_Allocation.xlsx',
                                'SF_collection_Input.csv',
                                'SF_collection_Input-Material_dependent.csv',
                                'SF_input_col.csv',
                                'SS_MRF_Input.csv',
                                'Reprocessing_Input.csv',
                                'WTE_Input.csv',                                
                                'Material properties - process modles.xlsx',
                                'Material properties.xlsx']}
                                                                

test_requirements = [ ]

files = None


setup(
    author="Mojtaba Sardarmehni",
    author_email='msardar2@ncsu.edu',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Education',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Scientific/Engineering :: Mathematics',
        'Topic :: Scientific/Engineering :: Visualization',
        'Natural Language :: English',
    ],
    description="Input data for swolfpy's life-cycle process models (swolfpy_inputdata)",
    install_requires=requirements,
    license="GNU GENERAL PUBLIC LICENSE V2",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='swolfpy_inputdata',
    name='swolfpy_inputdata',
    packages=find_packages(include=['swolfpy_inputdata', 'swolfpy_inputdata.*']),
    setup_requires=setup_requirements,
    package_data=package_input_data,
    data_files = files,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://bitbucket.org/swolfpy/swolfpy-inputdata',
    version='0.1.2',
    zip_safe=False,
)



# -*- coding: utf-8 -*-
"""
Created on Mon Jul  1 20:05:32 2019

@author: msardar2
"""
import pandas as pd
import numpy as np
from ..MC import *
class CommonData(MC):
    def __init__(self):
### Materials
        self.Index = ['Unit','Yard_Trimmings_Leaves', 'Yard_Trimmings_Grass', 'Yard_Trimmings_Branches', 'Food_Waste_Vegetable', 'Food_Waste_Non_Vegetable',
         'Wood', 'Wood_Other', 'Textiles', 'Rubber_Leather', 'Newsprint', 'Corr_Cardboard', 'Office_Paper', 'Magazines', 'third_Class_Mail',
         'Folding_Containers', 'Paper_Bags', 'Mixed_Paper', 'Paper_Non_recyclable', 'HDPE_Translucent_Containers', 'HDPE_Pigmented_Containers',
         'PET_Containers', 'Plastic_Other_1_Polypropylene', 'Plastic_Other_2', 'Mixed_Plastic', 'Plastic_Film', 'Plastic_Non_Recyclable',
         'Ferrous_Cans', 'Ferrous_Metal_Other', 'Aluminum_Cans', 'Aluminum_Foil', 'Aluminum_Other', 'Ferrous_Non_recyclable', 'Al_Non_recyclable',
         'Glass_Brown', 'Glass_Green', 'Glass_Clear', 'Mixed_Glass', 'Glass_Non_recyclable', 'Misc_Organic', 'Misc_Inorganic', 'E_waste',
         'Aerobic_Residual', 'Anaerobic_Residual', 'Bottom_Ash', 'Fly_Ash', 'Diapers_and_sanitary_products', 'Waste_Fraction_47', 'Waste_Fraction_48',
         'Waste_Fraction_49', 'Waste_Fraction_50', 'Waste_Fraction_51', 'Waste_Fraction_52', 'Waste_Fraction_53', 'Waste_Fraction_54', 'Waste_Fraction_55',
         'Waste_Fraction_56', 'Waste_Fraction_57', 'Waste_Fraction_58', 'Waste_Fraction_59', 'Waste_Fraction_60']
        
### Molecular Weights
        self.MW= {"C":{"Name":"Carbon MW","amount":12.011,"unit":"g/mol","Reference":None},
                "P":{"Name":"Phosphorus MW","amount":30.974,"unit":"g/mol","Reference":None},
                "H":{"Name":"Hydrogen MW","amount":1.008,"unit":"g/mol","Reference":None},
                "N":{"Name":"Nitrogen MW","amount":14.007,"unit":"g/mol","Reference":None},
                "O":{"Name":"Oxygen MW","amount":15.999,"unit":"g/mol","Reference":None},
                "K":{"Name":"K MW","amount":39.098,"unit":"g/mol","Reference":None},
                "S":{"Name":"S MW","amount":32.065,"unit":None,"Reference":None},
                "Cl":{"Name":"Cl MW","amount":35.453,"unit":None,"Reference":None},
                "H2":{"Name":"H2 MW","amount":2 * 1.008 ,"unit":"g/mol","Reference":None},
                "CO":{"Name":"CO MW","amount":12.011+15.999  ,"unit":"g/mol","Reference":None},
                "CO2":{"Name":"CO2 MW","amount":15.999 * 2 +12.011 ,"unit":"g/mol","Reference":None},
                "CH4":{"Name":"CH4 MW","amount":12.011 + 4 * 1.008,"unit":"g/mol","Reference":None},
                "H2O":{"Name":"H2O MW","amount":15.999 + 2 * 1.008,"unit":"g/mol","Reference":None},
                "SO2":{"Name":"SO2 MW","amount":2 * 15.999 + 32.065,"unit":"g/mol","Reference":None},
                "HCl":{"Name":"HCl MW","amount": 35.453 + 1.008 ,"unit":"g/mol","Reference":None},
                "NOx":{"Name":"HCl MW","amount": 14.007 + 2 * 15.999 ,"unit":"g/mol","Reference":None},
                "Hydrocarbons":{"Name":"Hydrocarbons MW","amount":86.18,"unit":None,"Reference":None},
                "Nitrous_Oxide":{"Name":"Nitrous_Oxide MW","amount": 2 * 14.007 + 15.999 ,"unit":None,"Reference":None},
                "Ammonia":{"Name":"Ammonia MW","amount": 14.007 + 3 * 1.008 ,"unit":None,"Reference":None},
                "Ammonium":{"Name":"Ammonium MW","amount": 14.007 + 4 * 1.008 ,"unit":None,"Reference":None},
                "Nitrate":{"Name":"Ammonia MW","amount": 14.007 + 3 * 15.999 ,"unit":None,"Reference":None}
                }      
        
### Unit Conversion
        self.UC = {'BTU_KJ':{"Name":"BTU to KJ","amount":1.055,"unit":"kJ","Reference":None},
                  'KJ_BTU':{"Name":"KJ to BTU","amount":1 / 1.055,"unit":"BTU","Reference":None}
                  }
        
        
### STP Measurements
        self.STP = {'mole_to_L':{"Name":"mole to Liter","amount":22.41 ,"unit":"L","Reference":None},
                   'm3CH4_to_kg':{"Name":"m3 CH4 to kg CH4","amount": 0.71589 ,"unit":"kg/m3","Reference":None},
                   'm3CO2_to_kg':{"Name":"m3 CO2 to kg","amount": self.MW['CO2']['amount']/22.41 ,"unit":"kg","Reference":None},
                   "Density_Air":{"Name":"Density_Air","amount":22.4,"unit":"L/mol","Reference":None}
                   }
        
        self.Evap_heat = {"Water_Evap_Heat":{"Name":"Water_Evap_Heat","amount":2.26,"unit":"MJ/Kg","Reference":None}}
        self.LHV ={'CH4':{'Name':'Energy content of methane','amount':37.7 ,'unit':'MJ/m3 at STP','Reference':None}}
        
### Land application inputs
        self.Land_app = {
                'cmpLandDies':{"Name":"Compost application diesel use","amount":0.8,"unit":'L/Mg compost',"Reference":None},
                'NO3runoff':{"Name":"Nitrogen runoff to surface water","amount":0.14,"unit":'kg N/kg N applied',"Reference":None},
                'NO3leach':{"Name":"Nitrogen leaching to ground water","amount":0.135,"unit":'kg N/kg N applied',"Reference":'23'},
                'MFEN':{"Name":"Nitrogen mineral fertilizer equivalent","amount":0.4,"unit":'kg N/kg N applied',"Reference":None},
                'MFEP':{"Name":"Phosphorus mineral fertilizer equivalent","amount":1,"unit":'kg N/kg N applied',"Reference":None},         
                'MFEK':{"Name":"Potassium mineral fertilizer equivalent","amount":1,"unit":'kg N/kg N applied',"Reference":None},
                'DslAppN':{"Name":"Fertilizer - Diesel fuel for application per kg N","amount":0.00229 ,"unit":'L/kg',"Reference":None},
                'DslAppP':{"Name":"Fertilizer - Diesel fuel for application per kg P","amount":0.00186 ,"unit":'L/kg',"Reference":None},
                'DslAppK':{"Name":"Fertilizer - Diesel fuel for application per kg K","amount":0.00125 ,"unit":'L/kg',"Reference":None},
                'fert_NO3Run':{"Name":"Fertilizer - Nitrate runoff to surface water","amount":10 ,"unit":'%',"Reference":None},
                'fert_NO3Leach':{"Name":"Fertilizer - Nitrate leaching to ground water","amount":10 ,"unit":'%',"Reference":None},
                'fert_N2O':{"Name":"Fertilizer - N released as N2O","amount":2.3 ,"unit":'%',"Reference":None},
                'fert_NH3':{"Name":"Fertilizer - N as NH3","amount":50 ,"unit":'%',"Reference":None},
                'fert_NH3Evap':{"Name":"Fertilizer - NH3 evaporated","amount":5 ,"unit":'%',"Reference":None}
                        }

#############################        
### Waste Water Treatment ###
############################# 
        
### Waste water Treatment
        self.WWT = {
                    'bod_rem':{"Name":"BOD Removal Efficiency","amount":97,"unit":'%',"Reference":'2'},
                    'cod_rem':{"Name":"COD Removal Efficiency","amount":95,"unit":'%',"Reference":'5'},
                    'tss_rem':{"Name":"TSS (Total suspended solids) Removal Efficiency","amount":96,"unit":'%',"Reference":'2'},
                    'n_rem':{"Name":"Total Nitrogen Removal Efficiency","amount":72,"unit":'%',"Reference":'5'},
                    'p_rem':{"Name":"Phosphate Removal Efficiency","amount":84,"unit":'%',"Reference":'5'},
                    'metals_rem':{"Name":"Metals Removal Efficiency","amount":85,"unit":'%',"Reference":'2'}
                    }

### Leachate Treatment  (BOD Treatment)
        self.Leachate_treat ={
                    'ad_leachDens':{"Name":"Leachate density","amount":1,"unit":'kg/L',"Reference":None},
                    'sludgef':{"Name":"Solid waste produced per volume of leachate","amount":1.20,"unit":'kg waste/m3 leachate',"Reference":'2'},
                    'co2bod':{"Name":"CO2 Biomass produced per BOD removed","amount":3.60,"unit":'kg CO2b/kg BOD',"Reference":'2'},
                    'elecBOD':{"Name":"Electricity used per mass of BOD removed","amount":0.99,"unit":'kWh/kg BOD removed',"Reference":'2'}
                    }
        self.Input_list = {'Land_app':self.Land_app, 'WWT':self.WWT, 'Leachate_treat':self.Leachate_treat}
### Monte_carlo          
    def setup_MC(self,seed=None):
        super().__init__(self.Input_list)
        super().setup_MC(seed)
        






























# -*- coding: utf-8 -*-
"""
Created on Wed Mar 27 12:25:05 2019

@author: msardar2
"""
import pandas as pd
import numpy as np
from ..MC import *

class WTE_input(MC):
    def __init__(self):
        ### WTE Economic Input Parameters
        self.Economic_parameters = {
                "WTE_lifetime":{"Name":"WTE Lifetime","amount":20,"unit":"years","Reference":None},
                "WTE_capacity_factor":{"Name":"WTE Capacity Factor","amount":0.91,"unit":None,"Reference":None},
                "Unit_WTE_capital_cost":{"Name":"Unit WTE Capital Cost","amount":520,"unit":"$/design tons per year","Reference":None},
                "Unit_WTE_O_M_cost":{"Name":"Unit WTE O&M Cost","amount":40,"unit":"$/Mg processed","Reference":None},
                "CF_I":{"Name":"Combustor Interest Rate","amount":0.05,"unit":None,"Reference":None}
                }
        
        ### Electricity Production Efficiency
        self.Elec_Prod_Eff = {
                "Gross_Efficiency":{"Name":"Gross Efficiency","amount":0.27,"unit":None,"Reference":None},
                "Net_Efficiency":{"Name":"Net Efficiency","amount":0.24,"unit":None,"Reference":None},
                "Heat_prod_Eff":{"Name":"Heat Production Efficiency","amount":0,"unit":None,"Reference":None}
                }
        
        ### Non-Metal Emissions at WTE Facility (Stack_Gas_Concentration)
        self.Stack_Gas_Conc_Non_metal ={
                "Sulfur_dioxide":{"Name":"Sulfur dioxide","amount":2,"unit":"ppmv @ 7% oxygen, dry","Reference":None},
                "HCl":{"Name":"HCl","amount":2,"unit":"ppmv @ 7% oxygen, dry","Reference":None},
                "NOx":{"Name":"NOx","amount":35,"unit":"ppmv @ 7% oxygen, dry","Reference":None},
                "CO":{"Name":"CO","amount":20,"unit":"ppmv @ 7% oxygen, dry","Reference":None},
                "PM":{"Name":"PM","amount":1.5,"unit":"mg/dscm  @ 7% oxygen, dry","Reference":None},
                "Dioxins_Furans":{"Name":"Dioxins / Furans","amount":1.5,"unit":"ng/dscm  @ 7% oxygen, dry","Reference":None},
                "Methane":{"Name":"Methane","amount":1.1,"unit":"ppmv @ 7% oxygen, dry","Reference":None},
                "Nitrous_Oxide":{"Name":"Nitrous Oxide","amount":1.3,"unit":"ppmv @ 7% oxygen, dry","Reference":None},
                "Ammonia":{"Name":"Ammonia","amount":2,"unit":"ppmv @ 7% oxygen, dry","Reference":None},
                "Hydrocarbons":{"Name":"Hydrocarbons","amount":1,"unit":"ppmv @ 7% oxygen, dry","Reference":None}
                }
        
        ### Metal Emissions at WTE Facility (Fraction in stack)
        self.Stack_metal_emission = {
                "As":{"Name":"As","amount":0.00012,"unit":None,"Reference":None},
                "Ba":{"Name":"Ba","amount":0,"unit":None,"Reference":None},
                "Cd":{"Name":"Cd","amount":0.00006,"unit":None,"Reference":None},
                "Cr":{"Name":"Cr","amount":0.00039,"unit":None,"Reference":None},
                "Cu":{"Name":"Cu","amount":0.00003,"unit":None,"Reference":None},
                "Hg":{"Name":"Hg","amount":0.00748,"unit":None,"Reference":None},
                "Ni":{"Name":"Ni","amount":0.00033,"unit":None,"Reference":None},
                "Pb":{"Name":"Pb","amount":0.00001,"unit":None,"Reference":None},
                "Sb":{"Name":"Sb","amount":0.00119,"unit":None,"Reference":None},
                "Se":{"Name":"Se","amount":0,"unit":None,"Reference":None},
                "Zn":{"Name":"Zn","amount":0,"unit":None,"Reference":None}
                }
        
        ### Metal Emissions at WTE Facility (Fraction in fly ash)
        self.Fly_Ash_metal_emission = {
                "As":{"Name":"As","amount":0.5892,"unit":None,"Reference":None},
                "Ba":{"Name":"Ba","amount":0,"unit":None,"Reference":None},
                "Cd":{"Name":"Cd","amount":0.8813,"unit":None,"Reference":None},
                "Cr":{"Name":"Cr","amount":0.1677,"unit":None,"Reference":None},
                "Cu":{"Name":"Cu","amount":0.0753,"unit":None,"Reference":None},
                "Hg":{"Name":"Hg","amount":0.9625,"unit":None,"Reference":None},
                "Ni":{"Name":"Ni","amount":0.1256,"unit":None,"Reference":None},
                "Pb":{"Name":"Pb","amount":0.5129,"unit":None,"Reference":None},
                "Sb":{"Name":"Sb","amount":0.5984,"unit":None,"Reference":None},
                "Se":{"Name":"Se","amount":0,"unit":None,"Reference":None},
                "Zn":{"Name":"Zn","amount":0.4818,"unit":None,"Reference":None}
                }
        
        ### Metal Emissions at WTE Facility (Fraction in bottom ash)
        self.Bottom_Ash_metal_emission = {
                "As":{"Name":"As","amount":0.41068,"unit":None,"Reference":None},
                "Ba":{"Name":"Ba","amount":1,"unit":None,"Reference":None},
                "Cd":{"Name":"Cd","amount":0.11864,"unit":None,"Reference":None},
                "Cr":{"Name":"Cr","amount":0.83191,"unit":None,"Reference":None},
                "Cu":{"Name":"Cu","amount":0.92647,"unit":None,"Reference":None},
                "Hg":{"Name":"Hg","amount":0.03002,"unit":None,"Reference":None},
                "Ni":{"Name":"Ni","amount":0.87407,"unit":None,"Reference":None},
                "Pb":{"Name":"Pb","amount":0.48709,"unit":None,"Reference":None},
                "Sb":{"Name":"Sb","amount":0.40041,"unit":None,"Reference":None},
                "Se":{"Name":"Se","amount":1,"unit":None,"Reference":None},
                "Zn":{"Name":"Zn","amount":0.5182,"unit":None,"Reference":None}
                }
        
        
        ### Metals Recovery
        self.Metals_Recovery={
        "Fe_Rec_Rate":{'Name':'Ferrous Recovery Rate from Bottom Ash','amount':0.9,"unit":None,"Reference":None}, 
        "Al_Rec_Rate":{'Name':'Aluminum Recovery Rate from Bottom Ash','amount':0.65,"unit":None,"Reference":None}, 
        "Cu_Rec_Rate":{'Name':'Copper Recovery Rate from Bottom Ash','amount':0.65,"unit":None,"Reference":None}, 
        "Fly_ash_frac":{'Name':'Fraction of Ash that Becomes Fly Ash','amount':0.05,"unit":None,"Reference":None}
                }
        
        ### Material Consumption
        self.Material_Consumption ={
        "lime":{'Name':'Mg lime/Mg MSW','amount':0.012,"unit":'Mg/Mgww',"Reference":None}, 
        "ammonia":{'Name':'Mg ammonia/Mg MSW','amount':0.0004,"unit":'Mg/Mgww',"Reference":None},
        "carbon":{'Name':'Mg carbon/Mg MSW','amount':0.0006,"unit":'Mg/Mgww',"Reference":None},
        "Distance_from_prod_fac":{'Name':'Distance_from_prod_fac','amount':100,"unit":'km',"Reference":None},
        "Empty_Return_Truck":{'Name':"Empty_Return_Truck",'amount':1,"unit":None,"Reference":None}
                }
        
### Monte_carlo          
    def setup_MC(self,seed=None):
        self.Input_list = {'Economic_parameters':self.Economic_parameters, 'Elec_Prod_Eff':self.Elec_Prod_Eff,'Stack_Gas_Conc_Non_metal':self.Stack_Gas_Conc_Non_metal,
                           'Stack_metal_emission':self.Stack_metal_emission, 'Fly_Ash_metal_emission':self.Fly_Ash_metal_emission,
                           'Bottom_Ash_metal_emission':self.Bottom_Ash_metal_emission,'Metals_Recovery':self.Metals_Recovery,
                           'Material_Consumption':self.Material_Consumption}
        super(WTE_input,self).__init__(self.Input_list )
        super().setup_MC(seed)    



#################################################################
#### Convering the input dictionaries to csv file
#################
A= WTE_input()
A.setup_MC()
category=[]
Parameter=[]
Name=[]
amount=[]
unit=[]

for x in A.Input_list.keys():
    for y in  A.Input_list[x].keys():
        category.append(x)
        Parameter.append(y)
        Name.append(A.Input_list[x][y]['Name'])
        amount.append(A.Input_list[x][y]['amount'])
        unit.append(A.Input_list[x][y]['unit'])
AAA={'category':category,'Parameter':Parameter,'Name':Name,'amount':amount,'unit':unit}



# -*- coding: utf-8 -*-
"""
Created on Mon Oct 21 22:52:32 2019

@author: msmsa
"""
from .InputData import InputData
from pathlib import Path
import pandas as pd


class SF_Col_Input(InputData):
    def __init__(self,input_data_path = None):
        if input_data_path:
            self.input_data_path = input_data_path
        else:
            self.input_data_path = Path(__file__).parent/'Data/SF_collection_Input.csv'
        
        # Initialize the superclass 
        super().__init__(self.input_data_path)
        
        ### Read Material properties related to the process        
        self.process_data = pd.read_csv(Path(__file__).parent/'Data/SF_collection_Input-Material_dependent.csv',index_col = 'Materials')
        self.process_data.fillna(0,inplace=True)

        ### Read input data        
        self.col=pd.read_csv(Path(__file__).parent/'Data/SF_input_col.csv',index_col='Name',usecols=['Name','RWC','SSR','DSR','MSR','LV','SSYW','SSO','DryRes','REC','WetRes','MRDO','SSYWDO','MSRDO'])
        self.col = self.col.transpose()